KMlogger
========

.. image:: https://travis-ci.org/kylemede/KMlogger.svg?branch=master
   :target: https://travis-ci.org/kylemede/KMlogger.svg?branch=master
 
A Python logging object that provided additional functionality beyond the standard module.


Installation Notes
==================
Currently KMlogger does not need installation directions.  Just copy the 
module and use it.  The dependencies are all reasonably standard python libraries.


License
-------

Copyright 2016 Kyle Mede and contributors.

KMlogger is free software made available under the GNU GPLv3 license. 
For details see the license.txt file.